==> nuphy2-0.3.3.tar.gz: nuphy2-0.3.3/README.md <==
# Some codes:
-

# Some databases
- http://nucleardata.nuclear.lu.se/toi/nuclide.asp?iZA=260059
- https://www.nndc.bnl.gov/nudat2/indx_dec.jsp

# Project: nuphy2

## Module: react




|            | In    | FireWrks   | Fully |        | In     |                          |                    |
| module     | Place | ParamCheck | Func  | Pytest | BinDir | description1             | description2       |
|------------+-------+------------+-------+--------+--------+--------------------------+--------------------|
| prj_utils  | y     | NO         | NEVER | NO     | NO     | Color,Fail,Print,GetFile |                    |
| isotope    | y     | y          | ~     | y      | y      | gives isotope data       | used by kinematics |
| kinematics | y     | y          | y     | y      | y      | kinematic calc           |                    |
| rolfs      | y     | y          | y     | y      |        |                          |                    |
| srim       | y     |            |       |        |        |                          |                    |
| xsections  |       |            |       |        |        |                          |                    |
| yields     |       |            |       |        |        |                          |                    |
| radcap     |       |            |       |        |        |                          |                    |
| tendl      |       |            |       |        |        |                          |                    |
|------------+-------+------------+-------+--------+--------+--------------------------+--------------------|
| fispact    |       |            |       |        |        | from nuphy1              |                    |
| sr         |       |            |       |        |        | nuphy1                   |                    |
| spectra    |       |            |       |        |        | nuphy1                   |                    |
./srim.py -i h1 -m al -e 24.4 -t 3mm -n 300 -w a.h5

==> nuphy2-0.3.10.tar.gz: nuphy2-0.3.10/README.md <==
# Examples:

Run 40MeV/A of 40Ar through mylar

```
/bin_nuphy2 sri -i ar40 -m mylar -e 1600 -t 3um
```


Run the same beam through 12cm of isobutane at 950 mbar 20deg C

```
./bin_nuphy2 sri -i ar40 -m hisobutane -e 1600 -t 120mm -p 95000 -k 293
```


Same through the layer of mylar+isobutane

```
./bin_nuphy2 sri -i ar40 -m hisobutane -e 1600 -t 120mm -p 95000 -k 293
```


Similar, two mylar windows:
```
./bin_nuphy2 sri -i ar40  -m mylar,hisobutane,mylar -e 1600 -t 3um,120mm,3um -p 95000 -k 293
```


# Some databases
- http://nucleardata.nuclear.lu.se/toi/nuclide.asp?iZA=260059
- https://www.nndc.bnl.gov/nudat2/indx_dec.jsp

# Project: nuphy2

## Module: react




|            | In    | FireWrks   | Fully |        | In     |                          |                    |
| module     | Place | ParamCheck | Func  | Pytest | BinDir | description1             | description2       |
|------------+-------+------------+-------+--------+--------+--------------------------+--------------------|
| prj_utils  | y     | NO         | NEVER | NO     | NO     | Color,Fail,Print,GetFile |                    |
| isotope    | y     | y          | ~     | y      | y      | gives isotope data       | used by kinematics |
| kinematics | y     | y          | y     | y      | y      | kinematic calc           |                    |
| rolfs      | y     | y          | y     | y      |        |                          |                    |
| srim       | y     |            |       |        |        |                          |                    |
| xsections  |       |            |       |        |        |                          |                    |
| yields     |       |            |       |        |        |                          |                    |
| radcap     |       |            |       |        |        |                          |                    |
| tendl      |       |            |       |        |        |                          |                    |
|------------+-------+------------+-------+--------+--------+--------------------------+--------------------|
| fispact    |       |            |       |        |        | from nuphy1              |                    |
| sr         |       |            |       |        |        | nuphy1                   |                    |
| spectra    |       |            |       |        |        | nuphy1                   |                    |
./srim.py -i h1 -m al -e 24.4 -t 3mm -n 300 -w a.h5
